/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import static org.apache.commons.lang3.StringUtils.*;

import java.util.Optional;
import java.util.regex.Pattern;

public class PortParser {

	private static final Pattern PORT_PATTERN = Pattern.compile("\\s*\\d{1,5}\\s*");

	public Integer parse(String portString) {
		if (isBlank(portString)) {
			return null;
		}
		if (!PORT_PATTERN.matcher(portString).matches()) {
			throw new IllegalArgumentException("Port must be a number");
		}
		return Optional.of(Integer.parseInt(portString.trim())).filter(port -> port > 0 && port < 65536)
				.orElseThrow(() -> new IllegalArgumentException("Port must be a number between 1 and 65535."));
	}
}
