/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle.attachment;

import static java.util.Objects.*;

import java.io.ByteArrayInputStream;
import java.net.URLConnection;

import org.apache.http.entity.ContentType;
import org.springframework.util.MimeTypeUtils;

import de.ozgcloud.formcycle.errorhandling.TechnicalException;
import de.xima.fc.entities.Attachment;

public class AttachmentMapper {

	static final String CANNOT_READ_ATTACHED_FILE = "Cannot read attached file. It doesn't exist.";
	static final String FILENAME_IS_NULL = "File name cannot be null.";

	public FormcycleAttachment map(Attachment pluginAttachment) {
		if (isNull(pluginAttachment.getFileEntity().getDaten())) {
			throw new TechnicalException(CANNOT_READ_ATTACHED_FILE);
		}
		return buildAttachment(pluginAttachment);
	}

	FormcycleAttachment buildAttachment(Attachment pluginAttachment) {
		return FormcycleAttachment.builder()
				.uuid(pluginAttachment.getUUID())
				.fileName(pluginAttachment.getDateiName())
				.contentType(getContentType(pluginAttachment.getDateiName()))
				.content(new ByteArrayInputStream(pluginAttachment.getFileEntity().getDaten())).build();
	}

	ContentType getContentType(String name) {
		if(isNull(name)) {
			throw new TechnicalException(FILENAME_IS_NULL);
		}
		String contentType = requireNonNullElse(URLConnection.guessContentTypeFromName(name), MimeTypeUtils.APPLICATION_OCTET_STREAM_VALUE);
		return ContentType.create(contentType);
	}

}
