/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle.client;

import org.apache.http.HttpStatus;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class HttpUtils {

	public static boolean isError(int statusCode) {
		return is400Error(statusCode) || is500Error(statusCode);
	}

	public static boolean is400Error(int statusCode) {
		return statusCode == HttpStatus.SC_BAD_REQUEST
				|| statusCode == HttpStatus.SC_UNAUTHORIZED
				|| statusCode == HttpStatus.SC_PAYMENT_REQUIRED
				|| statusCode == HttpStatus.SC_FORBIDDEN
				|| statusCode == HttpStatus.SC_NOT_FOUND
				|| statusCode == HttpStatus.SC_METHOD_NOT_ALLOWED
				|| statusCode == HttpStatus.SC_NOT_ACCEPTABLE
				|| statusCode == HttpStatus.SC_PROXY_AUTHENTICATION_REQUIRED
				|| statusCode == HttpStatus.SC_REQUEST_TIMEOUT
				|| statusCode == HttpStatus.SC_CONFLICT
				|| statusCode == HttpStatus.SC_GONE
				|| statusCode == HttpStatus.SC_LENGTH_REQUIRED
				|| statusCode == HttpStatus.SC_PRECONDITION_FAILED
				|| statusCode == HttpStatus.SC_REQUEST_TOO_LONG
				|| statusCode == HttpStatus.SC_REQUEST_URI_TOO_LONG
				|| statusCode == HttpStatus.SC_UNSUPPORTED_MEDIA_TYPE
				|| statusCode == HttpStatus.SC_REQUESTED_RANGE_NOT_SATISFIABLE
				|| statusCode == HttpStatus.SC_EXPECTATION_FAILED
				|| statusCode == HttpStatus.SC_INSUFFICIENT_SPACE_ON_RESOURCE
				|| statusCode == HttpStatus.SC_METHOD_FAILURE
				|| statusCode == HttpStatus.SC_UNPROCESSABLE_ENTITY
				|| statusCode == HttpStatus.SC_LOCKED
				|| statusCode == HttpStatus.SC_FAILED_DEPENDENCY
				|| statusCode == HttpStatus.SC_TOO_MANY_REQUESTS;
	}

	public static boolean is500Error(int statusCode) {
		return statusCode == HttpStatus.SC_INTERNAL_SERVER_ERROR
				|| statusCode == HttpStatus.SC_NOT_IMPLEMENTED
				|| statusCode == HttpStatus.SC_BAD_GATEWAY
				|| statusCode == HttpStatus.SC_SERVICE_UNAVAILABLE
				|| statusCode == HttpStatus.SC_GATEWAY_TIMEOUT
				|| statusCode == HttpStatus.SC_HTTP_VERSION_NOT_SUPPORTED
				|| statusCode == HttpStatus.SC_INSUFFICIENT_STORAGE;
	}
}
