/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle.formdata;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.Set;

import de.xima.fc.form.common.XPropertyEnum;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
@Getter
enum ItemClass {

	HEADER("XHeader", null),
	PAGE("XPage", null),
	FOOTER("XFooter", null),
	SPAN("XSpan", XPropertyEnum.rtevalue),
	FIELD_SET("XFieldSet", XPropertyEnum.legend),
	CONTAINER("XContainer", null),
	BUTTON_LIST("XButtonList", null),
	TEXT_FIELD("XTextField", XPropertyEnum.label),
	TEXT_AREA("XTextArea", XPropertyEnum.label),
	SELECT("XSelect", XPropertyEnum.label),
	CHECKBOX("XCheckbox", XPropertyEnum.label),
	UPLOAD("XUpload", XPropertyEnum.label);

	static final Set<ItemClass> ROOT_CONTAINERS = EnumSet.of(HEADER, PAGE, FOOTER);
	static final Set<ItemClass> NESTED_CONTAINER = EnumSet.of(CONTAINER, FIELD_SET);
	static final Set<ItemClass> INPUT_CLASSES = EnumSet.of(TEXT_FIELD, TEXT_AREA, SELECT, CHECKBOX, UPLOAD);

	private static final Map<String, ItemClass> cache = new HashMap<>();

	static {
		for (ItemClass e : values()) {
			cache.put(e.className, e);
		}
	}

	private final String className;
	private final XPropertyEnum titleProperty;

	public Optional<XPropertyEnum> getTitleProperty() {
		return Optional.ofNullable(titleProperty);
	}

	public static ItemClass fromString(String className) {
		return cache.get(className);
	}

	public static boolean isRootContainer(ItemClass className) {
		return ROOT_CONTAINERS.contains(className);
	}

	public static boolean isNestedContainer(ItemClass className) {
		return NESTED_CONTAINER.contains(className);
	}

	public static boolean isTextNode(ItemClass className) {
		return className == SPAN;
	}

	public static boolean isInputNode(ItemClass className) {
		return INPUT_CLASSES.contains(className);
	}
}
