/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle.formdata;

import java.util.List;
import java.util.Set;
import java.util.UUID;

import de.ozgcloud.formcycle.attachment.FormcycleAttachmentTestFactory;

public class FormDataTestFactory {

	public static final long FORM_ID = 1;
	public static final String FORM_ID_STR = String.valueOf(FORM_ID);
	public static final String FORM_NAME = "formular";
	public static final String ORGANISATIONS_EINHEIT_ID = "12345";
	public static final String ATTACHMENT_ID = "file.pdf";
	public static final String ATTACHMENT_UUID = UUID.randomUUID().toString();
	public static final String REPRESENTATION_UUID = UUID.randomUUID().toString();
	public static final String FIELD_VALUE_1 = "on";
	public static final List<FormNode> FIELD_DATA = List.of(FormNodeTestFactory.create());

	public static FormData create() {
		return createBuilder().build();
	}

	public static FormData.FormDataBuilder createBuilder() {
		return FormData.builder()
				.formId(FORM_ID)
				.formName(FORM_NAME)
				.organisationsEinheitId(ORGANISATIONS_EINHEIT_ID)
				.fieldData(FIELD_DATA)
				.attachmentNames(Set.of(ATTACHMENT_ID))
				.attachmentUuids(Set.of(ATTACHMENT_UUID))
				.representation(FormcycleAttachmentTestFactory.createBuilder().uuid(REPRESENTATION_UUID).build())
				.attachment(FormcycleAttachmentTestFactory.createBuilder().uuid(ATTACHMENT_UUID).build())
				.serviceKonto(ServiceKontoTestFactory.create());
	}
}
