/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle.formdata;

import static de.ozgcloud.formcycle.formdata.ItemClass.*;
import static org.mockito.Mockito.*;

import java.util.LinkedHashMap;
import java.util.Map;

import de.xima.fc.form.common.XPropertyEnum;
import de.xima.fc.form.common.items.XItem;
import de.xima.fc.form.common.models.XPropertyValue;

public class StructureMockFactory {

	public static final String ITEM_ID = "item-id";
	public static final String HEADER_ITEM_ID = "xi-header-1";
	public static final String PAGE_ITEM_ID = "xi-p-1";
	public static final String CONTAINER_ITEM_ID = "xi-div-1";
	public static final String FOOTER_ITEM_ID = "xi-footer-1";

	public static final String ITEM_TITLE = "item-title";
	public static final String ITEM_NAME = "item-name";

	public static Map<String, XItem> create() {
		Map<String, XItem> map = new LinkedHashMap<>();
		map.put(HEADER_ITEM_ID, getMock(HEADER));
		map.put(ITEM_ID + "-0", getMock(SPAN, HEADER_ITEM_ID));

		map.put(PAGE_ITEM_ID, getMock(PAGE));
		map.put(CONTAINER_ITEM_ID, getMock(CONTAINER, PAGE_ITEM_ID));
		map.put(ITEM_ID + "-1", getMock(TEXT_FIELD, CONTAINER_ITEM_ID));
		map.put(ITEM_ID + "-2", getMock(CHECKBOX, PAGE_ITEM_ID));

		map.put(FOOTER_ITEM_ID, getMock(FOOTER));
		map.put(ITEM_ID + "-3", getMock(SPAN, FOOTER_ITEM_ID));

		return map;
	}

	public static Map<String, XItem> createPageItem(){
		Map<String, XItem> map = new LinkedHashMap<>();
		map.put(PAGE_ITEM_ID, getMock(PAGE));
		return map;
	}
	public static Map<String, XItem> createItem(ItemClass itemClass) {
		Map<String, XItem> map = createPageItem();
		map.put(ITEM_ID, getMock(itemClass, PAGE_ITEM_ID));

		return map;
	}

	public static Map<String, XItem> createContainerWithItem(ItemClass container, ItemClass item) {
		Map<String, XItem> map = createPageItem();
		map.put(CONTAINER_ITEM_ID, getMock(container, PAGE_ITEM_ID));
		map.put(ITEM_ID, getMock(item, CONTAINER_ITEM_ID));

		return map;
	}

	public static XItem getMock(ItemClass itemClass) {
		return getMock(itemClass, getItemId(itemClass), "", ITEM_TITLE, ITEM_NAME);
	}

	public static XItem getMock(ItemClass itemClass, String parentId) {
		return getMock(itemClass, getItemId(itemClass), parentId, ITEM_TITLE, ITEM_NAME);
	}

	private static String getItemId(ItemClass itemClass) {
		switch (itemClass) {
		case HEADER:
			return HEADER_ITEM_ID;
		case PAGE:
			return PAGE_ITEM_ID;
		case CONTAINER:
			return CONTAINER_ITEM_ID;
		case FOOTER:
			return FOOTER_ITEM_ID;
		default:
			return ITEM_ID;
		}
	}

	public static XItem getMock(ItemClass itemClass, String itemId, String parentId, String title, String name) {
		XItem xItem = mock(XItem.class);
		lenient().when(xItem.getClassName()).thenReturn(itemClass.getClassName());
		lenient().when(xItem.getId()).thenReturn(itemId);
		lenient().when(xItem.getParentId()).thenReturn(parentId);
		lenient().when(xItem.getName()).thenReturn(name);
		lenient().when(xItem.get(any(XPropertyEnum.class))).thenReturn(mock(XPropertyValue.class));
		itemClass.getTitleProperty().ifPresent(titlePropertyKey -> {
			var propertyValue = new XPropertyValue(titlePropertyKey, title);
			lenient().when(xItem.get(titlePropertyKey)).thenReturn(propertyValue);
		});
		return xItem;
	}

}
